@@ -32,11 +32,16 @@
 #include <cstring>
 #include <stdint.h>
 #include <cstddef>
-#include <ETL/stringf>
+
 #include <libxml++/libxml++.h>
-#include "filecontainerzip.h"
+#include <glib/gstdio.h>
+
+#include <ETL/stringf>
+
 #include "zstreambuf.h"
 
+#include "filecontainerzip.h"
+
 #endif
 
 /* === U S I N G =========================================================== */
@@ -370,8 +375,8 @@ void FileContainerZip::read_history(std::list<HistoryRecord> &list, FILE *f, fil
 std::list<FileContainerZip::HistoryRecord> FileContainerZip::read_history(const String &container_filename)
 {
 	std::list<HistoryRecord> list;
-
-	FILE *f = fopen(container_filename.c_str(), "rb");
+	
+	FILE *f = g_fopen(fix_slashes(container_filename).c_str(), "rb");
 	if (f == NULL) return list;
 
 	fseek(f, 0, SEEK_END);
@@ -389,14 +394,16 @@ std::list<FileContainerZip::HistoryRecord> FileContainerZip::read_history(const
 bool FileContainerZip::create(const String &container_filename)
 {
 	if (is_opened()) return false;
-	storage_file_ = fopen(fix_slashes(container_filename).c_str(), "w+b");
+	storage_file_ = g_fopen(fix_slashes(container_filename).c_str(), "w+b");
+	
 	if (is_opened()) changed_ = true;
 	return is_opened();
 }
 
 bool FileContainerZip::open_from_history(const String &container_filename, file_size_t truncate_storage_size) {
 	if (is_opened()) return false;
-	FILE *f = fopen(fix_slashes(container_filename).c_str(), "r+b");
+	FILE *f = g_fopen(fix_slashes(container_filename).c_str(), "r+b");
+
 	if (f == NULL) return false;
 
 	// check size of file
