@@ -36,6 +36,7 @@
 #include <synfig/gradient.h>
 #include <synfig/general.h>
 #include <synfig/localization.h>
+#include <synfig/valuenode_registry.h>
 
 #endif
 
@@ -49,6 +50,8 @@ using namespace synfig;
 
 /* === G L O B A L S ======================================================= */
 
+REGISTER_VALUENODE(ValueNode_GradientColor, RELEASE_VERSION_0_61_09, "gradientcolor", "Gradient Color")
+
 /* === P R O C E D U R E S ================================================= */
 
 /* === M E T H O D S ======================================================= */
@@ -90,8 +93,8 @@ ValueNode_GradientColor::~ValueNode_GradientColor()
 ValueBase
 ValueNode_GradientColor::operator()(Time t)const
 {
-	if (getenv("SYNFIG_DEBUG_VALUENODE_OPERATORS"))
-		printf("%s:%d operator()\n", __FILE__, __LINE__);
+	DEBUG_LOG("SYNFIG_DEBUG_VALUENODE_OPERATORS",
+		"%s:%d operator()\n", __FILE__, __LINE__);
 
 	Real index((*index_)(t).get(Real()));
 	bool loop((*loop_)(t).get(bool()));
@@ -129,17 +132,7 @@ ValueNode_GradientColor::get_link_vfunc(int i)const
 	return 0;
 }
 
-String
-ValueNode_GradientColor::get_name()const
-{
-	return "gradientcolor";
-}
 
-String
-ValueNode_GradientColor::get_local_name()const
-{
-	return _("Gradient Color");
-}
 
 bool
 ValueNode_GradientColor::check_type(Type &type)
